@@ -1,9 +1,12 @@
+from textgrid_tools.intervals.between_marks_joining import join_intervals_between_marks
 from textgrid_tools.intervals.between_pause_joining import join_intervals_between_pauses
 from textgrid_tools.intervals.boundary_fixing import fix_interval_boundaries
 from textgrid_tools.intervals.boundary_joining import join_intervals_on_boundaries
 from textgrid_tools.intervals.duration_joining import join_intervals_on_durations
 from textgrid_tools.intervals.durations_plotting import plot_interval_durations_diagram
+from textgrid_tools.intervals.joining import join_intervals
 from textgrid_tools.intervals.mark_joining import join_marks
 from textgrid_tools.intervals.removing import remove_intervals
 from textgrid_tools.intervals.splitting import split_intervals
 from textgrid_tools.intervals.symbols_joining import join_interval_symbols
+from textgrid_tools.intervals.text_replacement import replace_text
