@@ -11,7 +11,16 @@ from time import perf_counter
 from typing import Callable, Dict, Generator, List, Tuple
 
 from textgrid_tools_cli import *
+from textgrid_tools_cli.grids.audio_paths_exporting import get_audio_paths_exporting_parser
+from textgrid_tools_cli.grids.audio_paths_importing import get_audio_paths_importing_parser
+from textgrid_tools_cli.grids.durations_labelling import get_grids_label_durations_parser
+from textgrid_tools_cli.grids.grid_durations_exporting import get_grid_durations_exporting_parser
+from textgrid_tools_cli.grids.grid_paths_exporting import get_grid_paths_exporting_parser
+from textgrid_tools_cli.grids.grid_paths_importing import get_grid_paths_importing_parser
+from textgrid_tools_cli.grids.pronunciations_exporting import get_pronunciations_exporting_parser
+from textgrid_tools_cli.grids.stats_generation import get_grids_plot_stats_parser
 from textgrid_tools_cli.helper import get_optional, parse_path
+from textgrid_tools_cli.intervals.text_replacement import get_text_replacement_parser
 from textgrid_tools_cli.logging_configuration import (configure_root_logger, get_file_logger,
                                                       try_init_file_logger)
 
@@ -34,9 +43,17 @@ def formatter(prog):
 
 def get_grids_parsers() -> Parsers:
   yield "merge", "merge grids together", get_grids_merging_parser
-  yield "export-vocabulary", "export vocabulary out of multiple grid files", get_vocabulary_export_parser
   yield "plot-durations", "plot durations", get_grids_plot_interval_durations_parser
+  yield "mark-durations", "mark intervals with specific durations with a text", get_grids_label_durations_parser
+  yield "create-dictionary", "create pronunciation dictionary out of a word and a pronunciation tier", get_pronunciations_exporting_parser
+  yield "plot-stats", "plot statistics", get_grids_plot_stats_parser
+  yield "export-vocabulary", "export vocabulary out of multiple grid files", get_vocabulary_export_parser
   yield "export-marks", "exports marks of a tier to a file", get_marks_exporting_parser
+  yield "export-durations", "exports durations of grids to a file", get_grid_durations_exporting_parser
+  yield "export-paths", "exports grid paths to a file", get_grid_paths_exporting_parser
+  yield "export-audio-paths", "exports audio paths to a file", get_audio_paths_exporting_parser
+  yield "import-paths", "import grids from paths written in a file", get_grid_paths_importing_parser
+  yield "import-audio-paths", "import audio files from paths written in a file", get_audio_paths_importing_parser
 
 
 def get_grid_parsers() -> Parsers:
@@ -64,15 +81,18 @@ def get_tier_parsers() -> Parsers:
 
 
 def get_intervals_parsers() -> Parsers:
-  yield "join-between-pauses", "join intervals between pauses", get_between_pause_joining_parser
+  yield "join", "join adjacent intervals", get_joining_parser
+  yield "join-between-marks", "join intervals between marks", get_between_marks_joining_parser
   yield "join-by-boundary", "join intervals by boundaries of a tier", get_boundary_joining_parser
   yield "join-by-duration", "join intervals by a duration", get_duration_joining_parser
   yield "join-marks", "join intervals containing specific marks", get_mark_joining_parser
   yield "join-symbols", "join intervals containing specific symbols", get_symbols_joining_parser
-  yield "fix-boundaries", "align boundaries of tiers according to a reference tier", get_boundary_fixing_parser
   yield "split", "split intervals", get_splitting_parser
+  yield "fix-boundaries", "align boundaries of tiers according to a reference tier", get_boundary_fixing_parser
   yield "remove", "remove intervals", get_intervals_removing_parser
   yield "plot-durations", "plot durations", get_plot_interval_durations_parser
+  yield "join-between-pauses", "join intervals between pauses (LEGACY, please use join-between-marks)", get_between_pause_joining_parser
+  yield "replace-text", "replace text using regex pattern", get_text_replacement_parser
 
 
 def get_parsers() -> Dict[str, Tuple[Parsers, str]]:
