@@ -6,6 +6,7 @@ from typing import Callable, List, Optional, Set, Tuple
 
 from ordered_set import OrderedSet
 from textgrid import TextGrid
+from tqdm import tqdm
 
 from textgrid_tools.helper import get_all_intervals
 from textgrid_tools.validation import InvalidGridError, NotExistingTierError, ValidationError
@@ -19,12 +20,13 @@ from textgrid_tools_cli.logging_configuration import get_file_logger, init_and_g
 def get_vocabulary_export_parser(parser: ArgumentParser) -> Callable:
   parser.description = "This command creates an vocabulary out of all words from multiple tiers in the grid files."
   add_directory_argument(parser)
-  add_tiers_argument(parser, "tiers that contains the words as intervals")
-  parser.add_argument("output", type=parse_path, metavar="output",
+  add_tiers_argument(
+    parser, "tiers that contains the words as intervals; must not contain line breaks")
+  parser.add_argument("output", type=parse_path, metavar="OUTPUT",
                       help="path to write the generated vocabulary")
   parser.add_argument("--include-empty", action="store_true",
                       help="include empty marker in vocabulary if any occurs")
-  add_encoding_argument(parser, "vocabulary encoding")
+  add_encoding_argument(parser, "OUTPUT encoding")
   return get_vocabulary_parsed
 
 
@@ -35,7 +37,7 @@ def get_vocabulary_parsed(ns: Namespace) -> ExecutionResult:
   grid_files = get_grid_files(ns.directory)
 
   grids: List[TextGrid] = []
-  for file_nr, (file_stem, rel_path) in enumerate(grid_files.items(), start=1):
+  for file_nr, (file_stem, rel_path) in enumerate(tqdm(grid_files.items(), desc="Reading grids", unit=" file(s)"), start=1):
     flogger.info(f"Processing {file_stem}")
     grid_file_in_abs = ns.directory / rel_path
     error, grid = try_load_grid(grid_file_in_abs, ns.encoding)
@@ -63,8 +65,12 @@ def get_vocabulary_parsed(ns: Namespace) -> ExecutionResult:
     logger.error(error.default_message)
     return False, False
 
+  any_word_contains_new_line = any("\n" in word for word in vocabulary)
+  if any_word_contains_new_line:
+    logger.warning("Some \"words\" contain line breaks, therefore the export does not contain each word on a new line! If you want to resolve this, remove the linebreaks from all intervals in the tiers you want to create a vocabulary from.")
+
   logger.info("Saving vocabulary...")
-  vocabulary_txt = '\n'.join(vocabulary)
+  vocabulary_txt = "\n".join(vocabulary)
   try:
     ns.output.write_text(vocabulary_txt, ns.encoding)
   except:
@@ -94,8 +100,8 @@ def get_vocabulary(grids: List[TextGrid], tier_names: Set[str], include_empty: b
       all_intervals = intervals
     else:
       all_intervals = chain(all_intervals, intervals)
-
-  all_marks_counter = Counter(interval.mark for interval in all_intervals)
+  all_marks_counter = Counter(interval.mark for interval in tqdm(
+    all_intervals, desc="Parsing intervals", unit=" interval(s)"))
   flogger = get_file_logger()
 
   flogger.info("Occurrences:")
