@@ -1,6 +1,7 @@
 import argparse
 import codecs
 import os
+import re
 from argparse import ArgumentParser, ArgumentTypeError
 from collections import OrderedDict
 from functools import partial
@@ -57,6 +58,20 @@ def get_all_files_in_all_subfolders(directory: Path) -> Generator[Path, None, No
       yield file_path
 
 
+def get_files_in_folder(directory: Path) -> Generator[Path, None, None]:
+  root, _, files = next(os.walk(directory))
+  for name in files:
+    file_path = Path(root) / name
+    yield file_path
+
+
+def get_subfolders(directory: Path) -> Generator[Path, None, None]:
+  root, folders, _ = next(os.walk(directory))
+  for name in folders:
+    file_path = Path(root) / name
+    yield file_path
+
+
 class ConvertToOrderedSetAction(argparse._StoreAction):
   def __call__(self, parser: argparse.ArgumentParser, namespace: argparse.Namespace, values: Optional[List], option_string: Optional[str] = None):
     if values is not None:
@@ -88,22 +103,22 @@ def add_overwrite_argument(parser: ArgumentParser) -> None:
 
 
 def add_output_directory_argument(parser: ArgumentParser) -> None:
-  parser.add_argument("-out", "--output-directory", metavar='PATH', type=get_optional(parse_path),
+  parser.add_argument("-out", "--output-directory", metavar='OUTPUT-PATH', type=get_optional(parse_path),
                       help="directory where to output the grids if not to the same directory")
 
 
 def add_directory_argument(parser: ArgumentParser, help_str: str = "directory containing the grids") -> None:
-  parser.add_argument("directory", type=parse_existing_directory, metavar="directory",
+  parser.add_argument("directory", type=parse_existing_directory, metavar="DIRECTORY",
                       help=help_str)
 
 
-def add_tiers_argument(parser: ArgumentParser, help_str: str) -> None:
-  parser.add_argument("tiers", metavar="tiers", type=parse_non_empty_or_whitespace,
+def add_tiers_argument(parser: ArgumentParser, help_str: str, meta_var: str = "TIER") -> None:
+  parser.add_argument("tiers", metavar=meta_var, type=parse_non_empty_or_whitespace,
                       nargs="+", help=help_str, action=ConvertToOrderedSetAction)
 
 
-def add_tier_argument(parser: ArgumentParser, help_str: str) -> None:
-  parser.add_argument("tier", metavar="tier", type=parse_non_empty_or_whitespace, help=help_str)
+def add_tier_argument(parser: ArgumentParser, help_str: str, meta_var: str = "TIER") -> None:
+  parser.add_argument("tier", metavar=meta_var, type=parse_non_empty_or_whitespace, help=help_str)
 
 # def add_overwrite_tier_argument(parser: ArgumentParser) -> None:
 #   parser.add_argument("-ot", "--overwrite-tier", action="store_true",
@@ -115,6 +130,11 @@ def add_n_jobs_argument(parser: ArgumentParser) -> None:
                       choices=range(1, cpu_count() + 1), default=DEFAULT_N_JOBS, help="amount of parallel cpu jobs")
 
 
+def add_dry_run_argument(parser: ArgumentParser) -> None:
+  parser.add_argument("-d", "--dry", action="store_true",
+                      help="dry run (i.e., don't change anything)")
+
+
 T = TypeVar("T")
 
 
@@ -136,6 +156,13 @@ def parse_path(value: str) -> Path:
   return path
 
 
+def parse_txt_path(value: str) -> Path:
+  value = parse_path(value)
+  if value.suffix.lower() != ".txt":
+    raise ArgumentTypeError("Value needs to be a .txt path!")
+  return value
+
+
 def parse_optional_value(value: str, method: Callable[[str], T]) -> Optional[T]:
   if value is None:
     return None
@@ -177,6 +204,15 @@ def parse_non_empty(value: Optional[str]) -> str:
   return value
 
 
+def parse_pattern(value: Optional[str]) -> re.Pattern:
+  value = parse_required(value)
+  try:
+    result = re.compile(value)
+  except re.error as error:
+    raise ArgumentTypeError("Value needs to be a valid pattern!") from error
+  return result
+
+
 def parse_non_empty_or_whitespace(value: str) -> str:
   value = parse_required(value)
   if value.strip() == "":
